DirectoryMonitor class
A class that monitors directory changes using native platform APIs
Properties
-
allowedExtensions
→ List<
String> -
final
- debugMode → bool
-
final
- dylib ↔ DynamicLibrary
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignoredFiles
→ List<
String> -
final
- recursive → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- watchDir → String
-
final
Methods
-
isLikelyFile(
String path) → bool - Returns true if the path is likely a file (based on extension or path format)
-
listen(
dynamic event(DirectoryMonitorEvent)) → void - Starts listening to directory changes and invokes callback for each event
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stop(
) → void - Stops the directory monitoring
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- matcher ↔ PathMatcher
-
latefinal
- packageRoot ↔ String
-
latefinal